@@ -138,11 +138,14 @@ def validate_host_port(host_port: str, listen: bool = False, multiple_hosts: boo
             hosts = hosts.split(",")
         else:
             hosts = [hosts]
+
+        # If host is set to "*" get all hostnames and/or IP addresses that the host would be able to listen to
         if "*" in hosts:
             if len(hosts) != 1:
                 raise ConfigParseError("expecting '*' alone")
-            # If host is set to "*" get all hostnames and/or IP addresses that the host would be able to listen to
-            hosts = [p[-1][0] for p in socket.getaddrinfo(None, port, 0, socket.SOCK_STREAM, 0, socket.AI_PASSIVE)]
+            # Filter out unexpected results when python is compiled with --disable-ipv6 and running on IPv6 system.
+            hosts = [a[4][0] for a in socket.getaddrinfo(None, port, 0, socket.SOCK_STREAM, 0, socket.AI_PASSIVE)
+                     if isinstance(a[4][0], str)]
         for host in hosts:
             # Check if "socket.IF_INET" or "socket.IF_INET6" is being used and instantiate a socket with the identified
             # protocol
