@@ -9,7 +9,14 @@ import click
 import etcd
 
 from click.testing import CliRunner
-from prettytable import ALL, PrettyTable
+from prettytable import PrettyTable
+
+try:
+    from prettytable import HRuleStyle
+    hrule_all = HRuleStyle.ALL
+except ImportError:
+    from prettytable import ALL as hrule_all
+
 from urllib3 import PoolManager
 
 from patroni import global_config
@@ -249,8 +256,8 @@ class TestCtl(unittest.TestCase):
     @patch('patroni.dynamic_loader.iter_modules', Mock(return_value=['patroni.dcs.dummy', 'patroni.dcs.etcd']))
     def test_get_dcs(self):
         with click.Context(click.Command('list')) as ctx:
-            ctx.obj = {'__config': {'dummy': {}}, '__mpp': get_mpp({})}
-            self.assertRaises(PatroniCtlException, get_dcs, 'dummy', 0)
+            ctx.obj = {'__config': {'dummy2': {}}, '__mpp': get_mpp({})}
+            self.assertRaises(PatroniCtlException, get_dcs, 'dummy2', 0)
 
     @patch('patroni.psycopg.connect', psycopg_connect)
     @patch('patroni.ctl.query_member', Mock(return_value=([['mock column']], None)))
@@ -392,6 +399,13 @@ class TestCtl(unittest.TestCase):
         result = self.runner.invoke(ctl, ctl_args, input='y')
         assert result.exit_code == 0
 
+        ctl_args = ['restart', 'alpha', '--pg-version', '99.0', '--pending', '--scheduled', '2300-10-01T14:30']
+        # normal restart, the schedule is actually parsed, but not validated in patronictl
+        mock_post.return_value.status = 200
+        result = self.runner.invoke(ctl, ctl_args, input='y')
+        assert result.exit_code == 0
+        assert 'might be different from the ones' in result.output
+
         # get restart with the non-200 return code
         # normal restart, the schedule is actually parsed, but not validated in patronictl
         mock_post.return_value.status = 204
@@ -682,6 +696,17 @@ class TestCtl(unittest.TestCase):
         show_diff(b"foo:\n  bar: \xc3\xb6\xc3\xb6\n".decode('utf-8'),
                   b"foo:\n  bar: \xc3\xbc\xc3\xbc\n".decode('utf-8'))
 
+    @patch('subprocess.Popen')
+    @patch('os.environ.get', Mock(return_value='cat'))
+    @patch('sys.stdout.isatty', Mock(return_value=True))
+    @patch('shutil.which', Mock(return_value='cat'))
+    def test_show_diff_pager(self, mock_popen):
+        show_diff("foo:\n  bar: 1\n", "foo:\n  bar: 2\n")
+        self.assertEqual(mock_popen.return_value.stdin.write.call_count, 6)
+        self.assertIn(b' bar: ', mock_popen.return_value.stdin.write.call_args_list[5][0][0])
+        self.assertIn(b' bar: ', mock_popen.return_value.stdin.write.call_args_list[4][0][0])
+        self.assertIn(b' foo:', mock_popen.return_value.stdin.write.call_args_list[3][0][0])
+
     @patch('subprocess.call', return_value=1)
     def test_invoke_editor(self, mock_subprocess_call):
         os.environ.pop('EDITOR', None)
@@ -747,7 +772,7 @@ class TestCtl(unittest.TestCase):
 class TestPatronictlPrettyTable(unittest.TestCase):
 
     def setUp(self):
-        self.pt = PatronictlPrettyTable(' header', ['foo', 'bar'], hrules=ALL)
+        self.pt = PatronictlPrettyTable(' header', ['foo', 'bar'], hrules=hrule_all)
 
     def test__get_hline(self):
         expected = '+-----+-----+'
